# eric7.Plugins.VcsPlugins.vcsMercurial.QueuesExtension.HgQueuesGuardsSelectionDialog

Module implementing a dialog to select a list of guards.

### Global Attributes

None

### Classes

HgQueuesGuardsSelectionDialog | Class implementing a dialog to select a list of guards.

### Functions

None

## HgQueuesGuardsSelectionDialog

Class implementing a dialog to select a list of guards.

### Derived from

QDialog, Ui_HgQueuesGuardsSelectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgQueuesGuardsSelectionDialog | Constructor
getData | Public method to retrieve the data.

### Static Methods

None

#### HgQueuesGuardsSelectionDialog (Constructor)

HgQueuesGuardsSelectionDialog(guards, activeGuards=None, listOnly=False, parent=None)

Constructor

guards
  list of guards to select from (list of strings)
activeGuards
  list of active guards (list of strings)
listOnly
  flag indicating to only list the guards (boolean)
parent
  reference to the parent widget (QWidget)

#### HgQueuesGuardsSelectionDialog.getData

getData()

Public method to retrieve the data.

Return:
  list of selected guards (list of strings)

Up